package
Version:
v0.0.0-...-4eea697
Opens a new window with list of versions in this module.
Published: Sep 26, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
ServiceName string `json:"service_name"`
CollectMetrics bool `json:"collect_metrics"`
MetricsPort int `json:"metrics_port"`
CollectTraces bool `json:"collect_traces"`
JaegerEndpoint string `json:"jaeger_endpoint"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.